Pyrugga is a library to help analyse rugby matches using Super Scout files from Opta.
Build time lines, match summary and descriptive statistics for a match. Pyrugga is
Licensed under GNU AFFERO GENERAL PUBLIC LICENSE. 
